@@ -2,9 +2,9 @@
  * 
  * scanone_em.h
  *
- * copyright (c) 2001-2, Karl W Broman, Johns Hopkins University
+ * copyright (c) 2001-4, Karl W Broman, Johns Hopkins University
  *
- * last modified Oct, 2002
+ * last modified Nov, 2004
  * first written Nov, 2001
  *
  * Licensed under the GNU General Public License version 2 (June, 1991)
@@ -32,13 +32,13 @@ void R_scanone_em(int *n_ind, int *n_pos, int *n_gen,
 		  double *intcov, int *n_intcov, double *pheno,
 		  double *weights,
 		  double *result, int *std_start, double *start,
-		  int *maxit, double *tol, int *trace);
+		  int *maxit, double *tol, int *verbose);
 
 /**********************************************************************
  * 
  * scanone_em
  *
- * Performs genotype scan using interval mapping.  (The multipoint
+ * Performs genome scan using interval mapping.  (The multipoint
  * genotype probabilities have already been calculated in 
  * calc.genoprob)
  * 
